pub struct Theme(pub HashMap<String, Style>);Expand description
Represents the theme of the application.
A theme is a collection of styles, each style is associated with a tag.
For example, the tag brand might be associated with a style that has
a specific color and bold attribute.
To apply a theme to a string, we need to format such string as something
similar to HTML. For example, the string This is a red text might be
formatted as <red>This is a red text</red>.
We can also thin of theme tags as styling components.
Tuple Fields
0: HashMap<String, Style>Implementations